==> ros-class-loader_0.3.8.orig.tar.gz: class_loader-0.3.8/test/plugins2.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <iostream>

#include "class_loader/class_loader.h"

#include "./base.h"

class Robot : public Base
{
public:
  virtual void saySomething() {std::cout << "Beep boop" << std::endl;}
};

class Alien : public Base
{
public:
  virtual void saySomething() {std::cout << "Znornoff!!!" << std::endl;}
};

class Monster : public Base
{
public:
  virtual void saySomething() {std::cout << "BEAAAHHHH" << std::endl;}
};

class Zombie : public Base
{
public:
  virtual void saySomething() {std::cout << "Brains!!!" << std::endl;}
};


CLASS_LOADER_REGISTER_CLASS(Robot, Base);
CLASS_LOADER_REGISTER_CLASS(Alien, Base);
CLASS_LOADER_REGISTER_CLASS(Monster, Base);
CLASS_LOADER_REGISTER_CLASS(Zombie, Base);

==> ros-class-loader_0.4.1.orig.tar.gz: class_loader-0.4.1/test/plugins2.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <iostream>

#include "class_loader/class_loader.hpp"

#include "./base.hpp"

class Robot : public Base
{
public:
  virtual void saySomething() {std::cout << "Beep boop" << std::endl;}
};

class Alien : public Base
{
public:
  virtual void saySomething() {std::cout << "Znornoff!!!" << std::endl;}
};

class Monster : public Base
{
public:
  virtual void saySomething() {std::cout << "BEAAAHHHH" << std::endl;}
};

class Zombie : public Base
{
public:
  virtual void saySomething() {std::cout << "Brains!!!" << std::endl;}
};


CLASS_LOADER_REGISTER_CLASS(Robot, Base)
CLASS_LOADER_REGISTER_CLASS(Alien, Base)
CLASS_LOADER_REGISTER_CLASS(Monster, Base)
CLASS_LOADER_REGISTER_CLASS(Zombie, Base)
